@@ -29,6 +29,7 @@ def test_membership():
     assert "red" not in Color
     assert "GREEN_GRASS" in Color
     assert "GREEN_grass" not in Color
+    assert "pink" not in Color
     assert None not in Color
     assert object() not in Color
     assert 121212 not in Color
@@ -68,6 +69,14 @@ def test_value_error_on_invalid_lookup():
         Color(None)
 
 
+def test_unique_on_each_side():
+    class ValidColor(DoubleSidedStrEnum):
+        RED_COLOR = "RED_COLOR"
+        BLUE_SKY = "BLUE_SKY"
+
+    assert ValidColor.RED_COLOR is ValidColor.RED_COLOR
+
+
 def test_unique_values():
     with pytest.raises(ValueError):
 
